@@ -32,7 +32,7 @@
 #include "ephy-marshal.h"
 #include "ephy-signal-accumulator.h"
 #include "ephy-permission-manager.h"
-#include "ephy-profile-migration.h"
+#include "ephy-profile-utils.h"
 #include "ephy-prefs.h"
 #include "ephy-settings.h"
 
@@ -293,14 +293,13 @@ ephy_embed_single_class_init (EphyEmbedSingleClass *klass)
 
   /**
    * EphyEmbedSingle::new-window:
-   * @single:
    * @parent_embed: the #EphyEmbed requesting the new window, or %NULL
    * @mask: a #EphyEmbedChrome
    *
    * The ::new_window signal is emitted when a new window needs to be opened.
    * For example, when a JavaScript popup window was opened.
    *
-   * Return a new #EphyEmbed.
+   * Returns: (transfer none): a new #EphyEmbed.
    **/
   g_signal_new ("new-window",
                 EPHY_TYPE_EMBED_SINGLE,
@@ -463,7 +462,7 @@ cache_size_cb (GSettings *settings,
                char *key,
                EphyEmbedSingle *single)
 {
-  int new_cache_size = g_settings_get_int (EPHY_SETTINGS_WEB, EPHY_PREFS_CACHE_SIZE);
+  int new_cache_size = g_settings_get_int (settings, key);
   webkit_soup_cache_set_max_size (single->priv->cache, new_cache_size * 1024 * 1024 /* in bytes */);
 }
 
@@ -482,6 +481,8 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
   char *filename;
   char *cookie_policy;
   char *cache_dir;
+  WebKitWebPluginDatabase* database;
+  GSList *list, *p;
   EphyEmbedSinglePrivate *priv = single->priv;
 
   /* Initialise nspluginwrapper's plugins if available */
@@ -545,6 +546,18 @@ ephy_embed_single_initialize (EphyEmbedSingle *single)
     soup_session_add_feature_by_type (session, SOUP_TYPE_PASSWORD_MANAGER_GNOME);
 #endif
 
+  /* Disable Flash by default, since it uses GTK+2.x and we can't mix
+   * it in our GTK+3.x process */
+  database = webkit_get_web_plugin_database ();
+  list = webkit_web_plugin_database_get_plugins (database);
+  for (p = list; p; p = p->next) {
+    WebKitWebPlugin *plugin = WEBKIT_WEB_PLUGIN (p->data);
+    if (g_strcmp0 (webkit_web_plugin_get_name (plugin), "Shockwave Flash") == 0)
+      webkit_web_plugin_set_enabled (plugin, FALSE);
+  }
+
+  webkit_web_plugin_database_plugins_list_free (list);
+
   return TRUE;
 }
 
@@ -620,11 +633,11 @@ ephy_embed_single_get_network_status (EphyEmbedSingle *single)
  * method and arguments: <code>window.open(&quot;@address&quot;,
  * &quot;_blank&quot;, &quot;@features&quot;);</code>.
  * 
- * Returns: the new embed. This is either a #EphyEmbed, or, when @features specified
- * "chrome", a #GtkMozEmbed.
+ * Returns: (transfer none): the new embed. This is either a #EphyEmbed, or,
+ * when @features specified "chrome", a #GtkMozEmbed.
  *
- * NOTE: Use ephy_shell_new_tab() unless this handling of the @features string is
- * required.
+ * NOTE: Use ephy_shell_new_tab() unless this handling of the @features string
+ * is required.
  */
 GtkWidget *
 ephy_embed_single_open_window (EphyEmbedSingle *single,
@@ -648,8 +661,8 @@ ephy_embed_single_open_window (EphyEmbedSingle *single,
  * The #EphyEmbedSingleFormAuthData structs and the #GSList are owned
  * by @single and should not be freed by the user.
  * 
- * Returns: #GSList with the possible auto-fills for the forms in
- * @uri, or %NULL
+ * Returns: (transfer none): #GSList with the possible auto-fills for the forms
+ * in @uri, or %NULL
  **/
 GSList *
 ephy_embed_single_get_form_auth (EphyEmbedSingle *single,
